@@ -4,7 +4,6 @@ from typing import Any
 
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.arm.base_resource_check import BaseResourceCheck
-from checkov.common.parsers.node import DictNode
 
 
 class AKSNetworkPolicy(BaseResourceCheck):
@@ -23,7 +22,7 @@ class AKSNetworkPolicy(BaseResourceCheck):
                 return CheckResult.FAILED
 
         properties = conf.get('properties')
-        if not properties or not isinstance(properties, DictNode):
+        if not properties or not isinstance(properties, dict):
             return CheckResult.FAILED
         network_profile = properties.get('networkProfile')
         if not network_profile:
