@@ -11,9 +11,6 @@ from checkov.circleci_pipelines.registry import registry
 from checkov.common.util.type_forcers import force_dict
 from checkov.runner_filter import RunnerFilter
 from checkov.yaml_doc.runner import Runner as YamlRunner
-from checkov.yaml_doc.runner import resolve_sub_name
-from checkov.yaml_doc.runner import resolve_image_name
-from checkov.yaml_doc.runner import resolve_step_name
 
 if TYPE_CHECKING:
     from checkov.common.checks.base_check_registry import BaseCheckRegistry
@@ -66,13 +63,17 @@ class Runner(ImageReferencerMixin["dict[str, dict[str, Any] | list[dict[str, Any
         if 'orbs.{orbs: @}' in supported_entities:
             new_key = "orbs"
         elif 'jobs.*.steps[]' in supported_entities:
-            job_name = resolve_sub_name(definition, start_line, end_line, tag='jobs')
-            step_name = resolve_step_name(definition['jobs'].get(job_name), start_line, end_line)
+            job_name = self.resolve_sub_name(definition, start_line, end_line, tag='jobs')
+            step_name = self.resolve_step_name(definition['jobs'].get(job_name), start_line, end_line)
             new_key = f'jobs({job_name}).steps{step_name}' if job_name else "jobs"
         elif 'jobs.*.docker[].{image: image, __startline__: __startline__, __endline__:__endline__}' in supported_entities:
-            job_name = resolve_sub_name(definition, start_line, end_line, tag='jobs')
-            image_name = resolve_image_name(definition['jobs'].get(job_name), start_line, end_line)
+            job_name = self.resolve_sub_name(definition, start_line, end_line, tag='jobs')
+            image_name = self.resolve_image_name(definition['jobs'].get(job_name), start_line, end_line)
             new_key = f'jobs({job_name}).docker.image{image_name}' if job_name else "jobs"
+        elif 'executors.*.docker[].{image: image, __startline__: __startline__, __endline__:__endline__}':
+            executor_name = self.resolve_sub_name(definition, start_line, end_line, tag='executors')
+            image_name = self.resolve_image_name(definition['jobs'].get(executor_name), start_line, end_line)
+            new_key = f'executors({executor_name}).docker.image{image_name}' if executor_name else "executors"
         return new_key
 
     def run(
