@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import json
 import logging
 from typing import List, Dict, Type, Optional, Tuple
@@ -11,7 +13,7 @@ from checkov.common.graph.db_connectors.db_connector import DBConnector
 from checkov.common.graph.graph_manager import GraphManager
 
 
-class CloudformationGraphManager(GraphManager[CloudformationLocalGraph]):
+class CloudformationGraphManager(GraphManager[CloudformationLocalGraph, "dict[str, DictNode]"]):
     def __init__(self, db_connector: DBConnector, source: str = "CloudFormation") -> None:
         super().__init__(db_connector=db_connector, parser=None, source=source)
 
