@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import concurrent.futures
+import logging
 import re
 from typing import List, Tuple, Dict, Any, Optional, Pattern, TYPE_CHECKING
 
@@ -120,8 +121,12 @@ class BaseAttributeSolver(BaseSolver):
         if self.is_jsonpath_check:
             parsed_attr = self.parsed_attributes.get(self.attribute)
             if parsed_attr is None:
-                parsed_attr = parse(self.attribute)
-                self.parsed_attributes[self.attribute] = parsed_attr
+                try:
+                    parsed_attr = parse(self.attribute)
+                    self.parsed_attributes[self.attribute] = parsed_attr
+                except Exception:
+                    logging.debug('Error parsing jsonpath expression', exc_info=True)
+                    raise
             for match in parsed_attr.find(vertex):
                 full_path = str(match.full_path)
                 if full_path not in vertex:
