@@ -66,3 +66,9 @@ class Operators:
     NOT_EQUALS_IGNORE_CASE = 'not_equals_ignore_case'
     RANGE_INCLUDES = 'range_includes'
     RANGE_NOT_INCLUDES = 'range_not_includes'
+    NUMBER_OF_WORDS_EQUALS = 'number_of_words_equals'
+    NUMBER_OF_WORDS_NOT_EQUALS = 'number_of_words_not_equals'
+    NUMBER_OF_WORDS_GREATER_THAN = 'number_of_words_greater_than'
+    NUMBER_OF_WORDS_GREATER_THAN_OR_EQUAL = 'number_of_words_greater_than_or_equal'
+    NUMBER_OF_WORDS_LESS_THAN = 'number_of_words_less_than'
+    NUMBER_OF_WORDS_LESS_THAN_OR_EQUAL = 'number_of_words_less_than_or_equal'
