@@ -16,19 +16,20 @@ MESSAGE_BRANCH_NOT_PROTECTED = 'Branch not protected'
 
 class BranchSecurity(BaseGithubCheck):
     def __init__(self, id: str, name: str) -> None:
-        categories = [CheckCategories.SUPPLY_CHAIN]
+        categories = (CheckCategories.SUPPLY_CHAIN,)
         super().__init__(
             id=id,
             name=name,
             categories=categories,
-            supported_entities=["*"],
-            block_type=BlockType.DOCUMENT
+            supported_entities=("*",),
+            block_type=BlockType.DOCUMENT,
         )
 
     def scan_entity_conf(self, conf: dict[str, Any], entity_type: str) -> CheckResult | None:  # type:ignore[override]
         if branch_security_schema.validate(conf):
             jsonpath_expression = parse("$..{}".format(self.get_evaluated_keys()[0].replace("/", ".")))
-            if all(match.value == self.get_expected_value() for match in jsonpath_expression.find(conf)):
+            matches = jsonpath_expression.find(conf)
+            if matches and all(isinstance(match.value, dict) or match.value == self.get_expected_value() for match in matches):
                 return CheckResult.PASSED
             else:
                 return CheckResult.FAILED
