@@ -1,6 +1,7 @@
 from collections.abc import Mapping
 from dataclasses import dataclass
 
+from checkov.common.bridgecrew.check_type import CheckType
 from checkov.common.checks.base_check_registry import BaseCheckRegistry
 
 
@@ -11,6 +12,8 @@ class EntityDetails:
 
 
 class ServerlessRegistry(BaseCheckRegistry):
+    def __init__(self):
+        super().__init__(CheckType.SERVERLESS)
 
     def extract_entity_details(self, entity: EntityDetails):
         return f"serverless_{entity.provider_type}", entity.data
@@ -25,7 +28,7 @@ class ServerlessRegistry(BaseCheckRegistry):
                 if check.id in [x['id'] for x in skipped_checks]:
                     skip_info = [x for x in skipped_checks if x['id'] == check.id][0]
 
-            if runner_filter.should_run_check(check):
+            if runner_filter.should_run_check(check, report_type=CheckType.SERVERLESS):
                 self.logger.debug("Running check: {} on file {}".format(check.name, scanned_file))
                 result = check.run(scanned_file=scanned_file, entity_configuration=entity_configuration,
                                    entity_name=entity_type, entity_type=entity_type, skip_info=skip_info)
