@@ -6,7 +6,8 @@ class CPURequests(BaseResourceCheck):
     def __init__(self):
         name = "CPU requests should be set"
         id = "CKV_K8S_10"
-        supported_resources = ["kubernetes_pod", "kubernetes_pod_v1"]
+        supported_resources = ['kubernetes_pod', 'kubernetes_pod_v1',
+                               'kubernetes_deployment', 'kubernetes_deployment_v1']
         categories = [CheckCategories.GENERAL_SECURITY]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
@@ -15,6 +16,15 @@ class CPURequests(BaseResourceCheck):
             self.evaluated_keys = [""]
             return CheckResult.FAILED
         spec = conf['spec'][0]
+        evaluated_keys_path = "spec"
+
+        template = spec.get("template")
+        if template and isinstance(template, list):
+            template = template[0]
+            template_spec = template.get("spec")
+            if template_spec and isinstance(template_spec, list):
+                spec = template_spec[0]
+                evaluated_keys_path = f'{evaluated_keys_path}/[0]/template/[0]/spec'
 
         containers = spec.get("container")
         if containers is None:
@@ -28,11 +38,11 @@ class CPURequests(BaseResourceCheck):
                     limits = resources.get('requests')[0]
                     if isinstance(limits, dict) and limits.get('cpu'):
                         return CheckResult.PASSED
-                    self.evaluated_keys = [f'spec/[0]/container/[{idx}]/resources/[0]/requests']
+                    self.evaluated_keys = [f'{evaluated_keys_path}/[0]/container/[{idx}]/resources/[0]/requests']
                     return CheckResult.FAILED
-                self.evaluated_keys = [f'spec/[0]/container/[{idx}]/resources']
+                self.evaluated_keys = [f'{evaluated_keys_path}/[0]/container/[{idx}]/resources']
                 return CheckResult.FAILED
-            self.evaluated_keys = [f'spec/[0]/container/[{idx}]']
+            self.evaluated_keys = [f'{evaluated_keys_path}/[0]/container/[{idx}]']
             return CheckResult.FAILED
         return CheckResult.PASSED
 
