@@ -10,12 +10,23 @@ class PrivilegedContainers(BaseResourceCheck):
         name = "Do not admit privileged containers"
         id = "CKV_K8S_16"
 
-        supported_resources = ['kubernetes_pod', 'kubernetes_pod_v1']
+        supported_resources = ['kubernetes_pod', "kubernetes_pod_v1",
+                               'kubernetes_deployment', 'kubernetes_deployment_v1']
         categories = [CheckCategories.GENERAL_SECURITY]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf) -> CheckResult:
         spec = conf['spec'][0]
+        evaluated_keys_path = "spec"
+
+        template = spec.get("template")
+        if template and isinstance(template, list):
+            template = template[0]
+            template_spec = template.get("spec")
+            if template_spec and isinstance(template_spec, list):
+                spec = template_spec[0]
+                evaluated_keys_path = f'{evaluated_keys_path}/[0]/template/[0]/spec'
+
         if spec.get("container"):
             containers = spec.get("container")
 
@@ -25,7 +36,7 @@ class PrivilegedContainers(BaseResourceCheck):
                 if container.get("security_context"):
                     context = container.get("security_context")[0]
                     if context.get("privileged") == [True]:
-                        self.evaluated_keys = [f'spec/[0]/container/[{idx}]/security_context/[0]/privileged']
+                        self.evaluated_keys = [f'{evaluated_keys_path}/[0]/container/[{idx}]/security_context/[0]/privileged']
                         return CheckResult.FAILED
         return CheckResult.PASSED
 
